import click

from eid_image_extractor.eid import Eid, EidNotInsertedException


@click.command()
@click.option(
    "--destination", help="Image from E-ID will be written to the following file"
)
def main(destination):
    try:
        click.echo("Reading E-ID data ⌛")
        eid = Eid()
        eid_image_decoded_string = eid.get_decoded_eid_image()
        destination_file = (
            destination if destination else f"{eid.get_national_number()}.jpg"
        )
        click.echo(f"Writing image from E-ID to file {destination_file} ⌛")
        with click.open_file(destination_file, "wb") as f:
            f.write(eid_image_decoded_string)
        click.echo(f"Done! ✅")
    except EidNotInsertedException:
        print("E-ID card not inserted, or could not be read ❌")


if __name__ == "__main__":
    main()



import base64

from eidreader import eid2dict


class EidNotInsertedException(Exception):
    pass


class Eid:
    def __init__(self):
        self.eid_data = self.get_eid_data()
        if not self.eid_inserted():
            raise EidNotInsertedException()

    def eid_inserted(self):
        return self.eid_data["success"]

    def get_eid_data(self):
        return eid2dict()

    def get_eid_image(self):
        return self.eid_data["PHOTO_FILE"]

    def get_decoded_eid_image(self):
        return base64.b64decode(self.get_eid_image())

    def get_national_number(self):
        return self.eid_data["national_number"]
